SystemOrganization addCategory: #ScriptLoader13!

Object subclass: #Loader
	instanceVariableNames: ''
	classVariableNames: 'PackagesBeforeLastLoad'
	poolDictionaries: ''
	category: 'ScriptLoader13'!

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
packageToBeTestedFolderName

	^ 'packages-to-be-tested'! !

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
waitingCacheFolder
	^ (FileDirectory default directoryNamed: self packageToBeTestedFolderName)
		assureExistence;
		yourself

	! !

!Loader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2010 17:41'!
allCurrentVersions
	"self new allCurrentVersions"
	
	| copies names |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	names := copies collect:
		[:ea |  ea ancestry ancestorString ].
	^ names reject: #isEmpty! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:51'!
currentChangedPackages
	"self new currentChangedPackages" 
	
	^  self currentPackages select: [:each |
		each needsSaving or: [
			(PackagesBeforeLastLoad includes: each ancestry ancestorString) not ] ]! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumber

	^ self class currentMajorVersionNumber ! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumberWithoutDot
	"self new currentMajorVersionNumberWithoutDot"
	^ self class currentMajorVersionNumber asString copyWithout: $.! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:42'!
currentVersionsToBeSaved
	"self new currentVersionsToBeSaved"
	
	^ self allCurrentVersions reject: [ :each |
		self packagesNotToSavePatternNames
			anySatisfy: [ :p | p match: each ] ]! !

!Loader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 9/10/2010 17:51'!
diffPackages
	"return a list of packages that are new. They can be dirty or not."
	"self new diffPackages"
	 
	| diff |
	diff := Set new.
	self currentVersionsToBeSaved do: [:each |
		(PackagesBeforeLastLoad includes: each) ifFalse: [diff add: each]].
	^ diff
	! !

!Loader methodsFor: 'initialize' stamp: 'StephaneDucasse 9/10/2010 17:49'!
initialize
	super initialize.
	PackagesBeforeLastLoad ifNil: [ PackagesBeforeLastLoad := Set new ]! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
markPackagesBeforeNewCodeIsLoaded
	"Use this method to keep a log of all the packages that were loaded before loading new code. This will help the system to perform a diff and know after what to publish."
	
	"self new markPackagesBeforeNewCodeIsLoaded"
	
	PackagesBeforeLastLoad := self currentVersionsToBeSaved! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:40'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
		).! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
resetPackagesBeforeLastLoad
	PackagesBeforeLastLoad := Set new! !

Loader subclass: #ScriptLoader
	instanceVariableNames: 'repository inboxRepository repository39 repositorySqueakTrunk repository310 repositoryTaskForces repositoryMC repositoryTreated'
	classVariableNames: 'CheckImageInSyncWithUpdate CurrentMajorVersionNumber CurrentScriptVersionNumber CurrentUpdateVersionNumber CurrentlyIntegratingChanges LogStream Repository'
	poolDictionaries: 'TextConstants'
	category: 'ScriptLoader13'!

!ScriptLoader commentStamp: 'StephaneDucasse 5/26/2010 20:49' prior: 0!
Pharo Process Description


---
Here is the pharo process.

General points
-----------------------
An enhancement
	- should be added to the bug tracker
	- announced to the mailing-list
	- asked for feedback 
	- results should be added to the BT entry

Fixed tag means ready for integration
Closed tag means integrated

A bug detected
	- discuss via the mailing-list
	- should be added to the bug tracker
	- fix are considered as enh (see point above)

When a fix is fixed it should be either post as cs to the BT entry or in the PharoInbox
as a Slice (a slice is an emtpy package that has as requirement other package composing the fix).

We have three projects:
	Pharo
	PharoInbox
	PharoTreatedInbox

A fix goes either from inbox to treatedInbox or to Pharo.
If a fix does not work it is moved to the TreatedInbox.
If a fix works it is integrated as follow - it will be moved from the Inbox to the TreatedInbox
and integrated and published in the Pharo project

To help browsing multiple repositories:

ScriptLoader new addExtraRepositories


+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Now the integration works in 4 main steps which can be steered by the following expression
ScriptLoader releaseMenu
or via the menu that can be shown/hidden using 
	ScriptLoader showIntegrationMenu
	ScriptLoader hideIntegrationMenu


1.) Start up a recent and clean image
	ScriptLoader new prepareNewUpdate
	
	This step will 
		- load the latest updates
		- load the latest ScriptLoader package from the Pharo repository.
		Indeed when we work on improving the ScriptLoader it may not be published in the update stream. 
		New versions can be available on the server but not part of the latest updates.
		Therefore the process always loads the latest version of scriptloader from the pharo repository.
		This point is important because when an integration failed, you have to check and optionally 
		remove the scriptloader package from the pharo repository.
		
		- check that the update.list (which contains the cs to load the packages) is in sync
		with the image current version. You have to download the latest version using a script like this one.
		Pay attention to update it so that it reflects the right version (ie 1.0, 1.1, 1.2...)
		     scp -p LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/updates.list .
		- snapshot the package version to detect dirty or changed but non dirty packages.

2.) Apply changes

	ScriptLoader new doneApplyingChanges
	
	This step will 
		- create an update method with can trigger the load of the packages and some pre/post actions
		- create a script method with describes all the package versions and it used by the update methods
		- save all the packages that are different (except some filtered packages)	
		into a local folder named package-to-be-tested.
		ScriptLoader, SLICE*.... and a couple of other packages are not considered to be included in the script method
			(check method packagesNotToSavePatternNames)
		

3.) Verify changes
	==> in a ***new*** image (in the current folder) execute:
	ScriptLoader new verifyNewUpdate

	This step will 
		- load in any order (so may break) the package previously saved
		in the packages to be tested.
		- this step is important because you may get simple changes with unexpected side effects and that 
		may break the load.
		

4.) If there are problems go to 2.) to fix them, else:
	ScriptLoader new publishChanges

	This step will
		- generate a new cs file whose purpose is to load the given version of the scriptloader and trigger the 
		correct update method.
		- add the name of the cs file to the end of the updates.list file local to the disc
		- copy all the package from the local directory to the Pharo
		
	After the updates.list and the cs file should be manually uploaded to the ftp (see below) 
	   scp "$1" LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/
	

5) in case of problems.
Think that if you pass the step 4 you may have a scriptLoader version that got published and that is reloaded 
during the first step.



CurrentMajorVersionNumber should contains a string '1.0', '1.1'....
This string will determine on which folder on the server the updates.list should be loaded.
	i.e., updates/pharo1.0, updates/pharo1.1 ....

--- Not to forget ---
To change the release stream
add a new method for each releaseStream
	ScriptLoader toPharoOne
	ScriptLoader toPharoOneDotOne
!

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 9/10/2010 17:28'!
checkImageInSyncWithUpdate
	"most of the time you want to make sure that your image is in sync with the latest item of the update.list
	but in some cases you do not to get forced to have this behavior."
	
	^ CheckImageInSyncWithUpdate ifNil: [CheckImageInSyncWithUpdate := true]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate: aBoolean

	CheckImageInSyncWithUpdate := aBoolean! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:15'!
currentMajorVersionNumber

	^ CurrentMajorVersionNumber ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:12'!
currentMajorVersionNumber: aNumber

	CurrentMajorVersionNumber := aNumber! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:06'!
currentlyIntegratingChanges

	CurrentlyIntegratingChanges isNil ifTrue: [self hideIntegrationMenu].
	^ CurrentlyIntegratingChanges! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:32'!
defaultMCWaitingFolder
	"self defaultMCWaitingFolder" 
	
	^ MCDirectoryRepository new directory: self waitingCacheFolder! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			(self new)
				installGofer;
				gofer ]! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
hideIntegrationMenu

	CurrentlyIntegratingChanges := false.! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'StephaneDucasse 9/10/2010 17:24'!
initialize
	self flag: #shouldRemoveNumber.
	CurrentMajorVersionNumber :=  1.2! !

!ScriptLoader class methodsFor: 'private' stamp: 'al 11/1/2008 20:03'!
loadLatestPackage: aString from: aPath
	| repository |
	
	repository := MCHttpRepository
		location: aPath
		user:  ''
		password: ''.
	self loadLatestPackage: aString fromRepository: repository! !

!ScriptLoader class methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
loadLatestPackage: aString fromRepository: aRepository
	| versionsBlock versions tries |
	
	versionsBlock := [ (aRepository allVersionNames select: [ :each |
		each beginsWith: aString ])
		asSortedCollection: [ :a :b |
			(a copyAfterLast: $.) asNumber <= (b copyAfterLast: $.) asNumber]].
	versions := versionsBlock value.
	tries := 0.
	[ versions isEmpty and: [ tries < 3 ] ] whileTrue: [
		versions := versionsBlock value.
		tries := tries + 1 ].
	versions isEmpty ifTrue: [ self error: 'problems when accessing squeaksource' ].
	
	aRepository versionReaderForFileNamed: (versions last , '.mcz') do: [:reader | | version |
		version := reader version.
		version load.
		version workingCopy repositoryGroup addRepository: aRepository]! !

!ScriptLoader class methodsFor: 'private' stamp: 'AlexandreBergel 10/23/2008 15:31'!
loadLatestPackage: aString fromSqueaksource: aDirectoryName
	" self loadLatestPackage: 'ScriptLoader' fromSqueaksource: 'Pharo' "

	self loadLatestPackage: aString from: 'http://www.squeaksource.com/', aDirectoryName
	! !

!ScriptLoader class methodsFor: 'menu' stamp: 'AlainPlantec 10/19/2010 22:47'!
menuCommandOn: aBuilder 
	<worldMenu> 
	
	(aBuilder item: #'Integrator Menu')
		order: 1.5;
		precondition: [self currentlyIntegratingChanges];
		parent: #System;
		icon: UITheme current smallAuthoringToolsIcon;
		action: [ScriptLoader releaseMenu]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 11/9/2010 18:39'!
releaseMenu
	"self releaseMenu"
	|symbol|
	symbol := UIManager default
		chooseFrom: #('1- Prepare new update'
		                        '2- Save new image for testing (optional)'
						'3- Freeze changes: packages will be saved (required)'
						'4- Verify new update (open the mother image in the same folder) (optional)'
						'5- Publish changes')
		values: #(prepareNewUpdate saveImageForRunningTests doneApplyingChanges verifyNewUpdate publishChanges).
	symbol ifNotNil: [ScriptLoader new perform: symbol]! !

!ScriptLoader class methodsFor: 'public' stamp: 'adrian-lienhard 6/6/2009 11:46'!
resetLogStream
	LogStream := nil! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
showIntegrationMenu

	CurrentlyIntegratingChanges := true.! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOne

	self currentMajorVersionNumber: 1.0! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOneDotOne

	self currentMajorVersionNumber: 1.1! !

!ScriptLoader class methodsFor: 'public' stamp: 'MarcusDenker 1/18/2011 16:56'!
toPharoOneDotThree

	self currentMajorVersionNumber: 1.3! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 5/14/2010 22:21'!
toPharoOneDotTwo

	self currentMajorVersionNumber: 1.2! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 2/25/2010 18:22'!
CSForLastUpdate: aString
	"ScriptLoader new CSForLastUpdate: 'cleanUpMethods'"
	
	| str updateNumber filename|
	updateNumber := self getLatestUpdateNumber.
	filename := updateNumber asString, '-Pha-', aString, '.cs'.
	FileDirectory default 
		forceNewFileNamed:  filename
		do: [ :stream | 
					self 
						generateCS: self latestScriptLoaderPackageIdentificationString
						fromUpdate: updateNumber on: stream].
	^ filename! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2010 22:31'!
CSForLastUpdateAndPatchUpdatesList: aString
	"ScriptLoader new CSForLastUpdateAndPatchUpdatesList: 'cleanUpMethods'"
	| filename |
	filename := self CSForLastUpdate: aString.
	self updateUpdatesList: aString.
	^ filename ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addExtraRepositories
	
	"self new addExtraRepositories"
	
	self addRepository39ToAllPackages.
	self addRepository310ToAllPackages.
	self addRepositoryTaskForcesToAllPackages.
	self addRepositorySqueakTrunkToAllPackages.
	self addRepositoryMCToAllPackages.
	self addRepositoryTreatedToAllPackages.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 21:51'!
addHomeRepositoryToAllPackages
	"self new addHomeRepositoryToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			addRepository: self repositoryTreated ].
		
	MCRepositoryGroup default
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			 addRepository: self repositoryTreated.
	
		
	
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 17:40'!
addHomeRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 10/18/2009 16:11'!
addPackage: aString
	"to be tested" 
	
	| workingCopy |
	PackageInfo registerPackageName: aString.
	workingCopy := MCWorkingCopy forPackage: (MCPackage new name: aString)! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/13/2009 15:48'!
addRepository310ToAllPackages
	"self new addRepository310ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository310
			].
	
	! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/6/2009 17:38'!
addRepository39ToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepository39ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository39
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/14/2009 10:31'!
addRepositoryMCToAllPackages
	
	"self new addRepositoryMCToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryMC
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2009 20:47'!
addRepositorySqueakTrunkToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepositorySqueakTrunkToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositorySqueakTrunk
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/13/2009 15:59'!
addRepositoryTaskForcesToAllPackages
	"self new addRepositoryTaskForcesToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTaskForces
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 10/31/2005 18:01'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addRepositoryTreatedToAllPackages
	"self new addRepositoryTreatedToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTreated
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentDirtyPackages
	"ScriptLoader new allCurrentDirtyPackages"
	"return all the current dirty packages even the ones that we do not want to save"

	
	^  self allCurrentPackages select: [:each | each needsSaving].

	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentPackages
	"ScriptLoader new allCurrentPackages" 
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:26'!
announceOnMailingList
	"
	self new announceOnMailingList"
	|title|
	title := '[update ', self currentMajorVersionNumber asString , '] #', self currentUpdateVersionNumber asString.
UIManager default
	edit: title, String cr, self currentUpdateVersionNumber asString, '
-----

', self commentForCurrentUpdate
	label: title.! !

!ScriptLoader methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
buildConfigurationMapFor: packageNames

	| configurationMap |
	configurationMap := MCConfiguration new.
	configurationMap repositories
		add: self repository;
		add: self inboxRepository.

	packageNames do: [:packageName | | version depArray |
		version := self loadVersionFromFileNamed: packageName.
		depArray := { version package name. version info name. version info id asString. }.
		configurationMap dependencies add: (MCConfiguration dependencyFromArray: depArray)].
	^configurationMap! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'MarcusDenker 1/19/2011 15:42'!
checkImageIsUptodate

	| stream last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	stream := FileDirectory default oldFileNamed: 'updates.list'.
	stream contents linesDo: [ :each | last := each ].
	stream close.
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 11/13/2010 22:31'!
cleanRepositories
	"self new cleanRepositories"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllRepositories.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarianoMartinezPeck 1/6/2011 20:02'!
cleanUpForProduction
	"self new cleanUpForProduction"
	
	| oldDicts newDicts |
	
	"trim MC ancestory information"
	MCVersionInfo allInstances do: [ :each | each instVarNamed: 'ancestors' put: nil ].	

	"delete logo"	
	LogoImageMorph default: nil.

	"delete ScriptLoader log"
	ScriptLoader resetLogStream.

	(MCPackage named: 'HelpSystem') unload.
	Smalltalk globals at: #SUnitUnloader ifPresent:[ :unloader | unloader new unloadAll  ].

	"shrink method dictionaries."
	Smalltalk garbageCollect.
	oldDicts := MethodDictionary allInstances.
	newDicts := Array new: oldDicts size.
	oldDicts withIndexDo: [ :d :index | newDicts at: index put: d rehashWithoutBecome ].
	oldDicts elementsExchangeIdentityWith: newDicts.
	oldDicts := newDicts := nil.
	
	self removeDejaVuFonts.
	(MCPackage named: 'Graphics-Resources') unload.
	
	(MCPackage named: 'HostMenus') unload.
	
	self cleanUpForRelease.
	(MCPackage named: self theScriptLoaderPackageName) unload.
	Smalltalk garbageCollect
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AlainPlantec 1/28/2011 21:44'!
cleanUpForRelease
	"self new cleanUpForRelease"

	Author fullName: 'Mr.Cleaner'.
	DebuggerMethodMap withAllSubclassesDo: [ :each | each voidMapCache ].
	self cleanUpPackageOrganizer.
	self cleanUpMethods.
	DataStream initialize.
	GradientFillStyle initPixelRampCache.
	FreeTypeCache clearCurrent.
	ImageMorph classPool at: #DefaultForm put: (Form extent: 1 @ 1 depth: 1).
	Behavior flushObsoleteSubclasses.
	MethodChangeRecord allInstancesDo: [ :x | x noteNewMethod: nil ].
	World cleanseOtherworldlySteppers.
	Smalltalk organization removeEmptyCategories.
	Browser initialize.
	SystemBrowser removeObsolete.
	AppRegistry removeObsolete.
	FileServices removeObsolete.
	MCFileBasedRepository flushAllCaches.
	MCMethodDefinition shutDown. 
	MCDefinition clearInstances.
	Smalltalk globals
		at: #TTFontDescription
		ifPresent: [ :c | 
			c
				clearDefault;
				clearDescriptions ].
	ExternalDropHandler resetRegisteredHandlers.
	Undeclared removeUnreferencedKeys.
	Smalltalk globals flushClassNameCache.
	ScrollBar initializeImagesCache.
	FreeTypeFontProvider current initialize.
	NaturalLanguageTranslator classPool at: #AllKnownPhrases put: nil.
	FreeTypeFontProvider current initialize.
	SystemNavigation default
		allObjectsDo: [ :each | 
			(each respondsTo: #releaseCachedState)
				ifTrue: [ each releaseCachedState ] ].
	3 timesRepeat: [ 
		Smalltalk garbageCollect.
		Symbol compactSymbolTable ].
	HashedCollection rehashAll.
	
	"Remove empty categories, which are not in MC packages, because MC does
	not do this (this script does not make packages dirty)"
	Smalltalk organization removeEmptyCategories.
	Smalltalk
		allClassesAndTraitsDo: [ :class |
			[ :each |
				each
					removeEmptyCategories;
					sortCategories ]
						value: class organization;
						value: class class organization ].
	PackageOrganizer default packages
		do: [ :each | each methods ifEmpty: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'.
	Smalltalk organization sortCategories.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	RecentMessageList cleanUp.
	Smalltalk garbageCollect.
	Author reset! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/5/2010 11:12'!
cleanUpMethods
	"Make sure that all methods in use are restarted"
	"ScriptLoader new cleanUpMethods"

	WeakArray restartFinalizationProcess.
	MethodChangeRecord allInstancesDo: [:x | x noteNewMethod: nil].
	WorldState allInstancesDo: [ :ws | ws convertAlarms; convertStepList; resetWorldMenu].
	WorldState allInstancesDo: [ :ws | ws instVarNamed: 'menuBuilder' put: nil ].
	ExternalDropHandler initialize.
	ScrollBar initializeImagesCache.
	GradientFillStyle initPixelRampCache.
	ProcessBrowser initialize.
	Smalltalk garbageCollect.
	Delay startTimerEventLoop! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 12/5/2009 11:19'!
cleanUpPackageOrganizer

	PackageOrganizer default packages
		do: [ :each | 
			each methods isEmpty
				ifTrue: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'! !

!ScriptLoader methodsFor: 'public' stamp: 'StephaneDucasse 1/31/2011 16:56'!
commentForCurrentUpdate
 ^ '- Issue 3630:	Add ensureCr convenience method.
- Issue 3562:	Deferred UI messages executed slowly. Thanks Ricardo Moran!!!!'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 14:36'!
compileNewUpdateMethod
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethod)
		classified: 'pharo - updates'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 13:26'!
compileScriptMethodWithCurrentPackages: aNumber 
	"ScriptLoader new compileScriptMethodWithCurrentPackages: 9999"
	
	self class compile: 
		(self newGenerateScriptTemplateWithCurrentPackages: aNumber)
		classified: 'pharo - scripts'! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
copyPackagesFromWaitingFolderToHomeRepository
	"self defaultMCWaitingFolder allFileNames"
	"self new copyPackageFromWaitingFolderToHomeRepository"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		self repository storeVersion: version]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'al 11/1/2008 19:49'!
currentPackages
	"self new currentPackages" 
	
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies reject: [:each |
		self packagesNotToSavePatternNames
			anySatisfy: [:p | p match: each package name]].
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:08'!
currentScriptVersionNumber
	^ CurrentScriptVersionNumber! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 9/8/2009 14:41'!
currentUpdateVersionNumber
	^ CurrentUpdateVersionNumber ifNil: [SystemVersion current highestUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 5/29/2006 20:52'!
currentVersions
	"ScriptLoader new currentVersions"
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies collect:
		[:ea |  ea ancestry ancestorString ]! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:46'!
deletePackage: aString

	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	MCWorkingCopy registry removeKey: toRemove package.! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 22:54'!
doneApplyingChanges
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	
	comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		centerAt: Sensor cursorPoint
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self].
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersion.
	self saveLatestScriptLoaderToWaitingFolder.
	
	self inform: 'Update prepared and ready to be verified.'! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 12:33'!
fixObsoleteReferences
	"self new fixObsoleteReferences"
	CompiledMethod allInstances
		do: [ :method | 
			| obsoleteBindings |
			obsoleteBindings := method literals
				select: [ :literal | literal isVariableBinding 
									and: [ literal value isBehavior and: [ literal value isObsolete ]] ].
			obsoleteBindings
				do: [ :binding | 
					| realClass obsName realName |
					obsName := binding value name.
					Transcript
						show: obsName;
						cr.
					realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
					realClass := Smalltalk globals at: realName asSymbol ifAbsent: [ UndefinedObject ].
					binding key: binding key value: realClass ] ].
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [ SystemNavigation default obsoleteBehaviors inspect ]! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 3/14/2010 12:44'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 8/14/2008 16:06'!
generateCS: packageInfo fromUpdate: updateNumber on: st
	
	st nextPutAll:
'"Postscript:
Leave the line above, and replace the rest of this comment by a useful one.
Executable statements should follow this comment, and should
be separated by periods, with no exclamation points (!!!!).
Be sure to put any further comments in double-quotes, like this one."

|repository|
repository := MCHttpRepository
                location: ''http://www.squeaksource.com/Pharo/''
                user: ''''
                password: ''''.
(repository loadVersionFromFileNamed:' .
	st nextPut: $' ; nextPutAll: packageInfo, '.mcz'') load.'; cr.
	st nextPutAll: 'ScriptLoader new update', (updateNumber) asString; nextPutAll: '.' ; cr.
	st nextPutAll: '!!'.
	^ st contents
! !

!ScriptLoader methodsFor: 'utils' stamp: 'stephane.ducasse 7/4/2009 12:27'!
generateCompleteFixList
	"generateCompleteFixList"
	| stream |
	stream := (FileStream newFileNamed: 'changes-log.txt').
	[ stream nextPutAll: ScriptLoader new logStream contents ] ensure: [ stream close ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 8/30/2009 14:48'!
generateNewUpdateMethod
	"ScriptLoader new generateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, '.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:05'!
generateScriptAndUpdateMethodForNewVersion
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethod.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 14:41'!
generateScriptTemplateWithAllCurrentPackages
	"ScriptLoader new generateScriptTemplateWithAllCurrentPackages"
	
	| str |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'scriptXXX' ; cr ; cr ; tab.
	str nextPutAll: '| names|'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	self currentVersionsToBeSaved do: 
		[:each |
			str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 18:07'!
generateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '| names |'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'al 11/1/2008 18:15'!
getLatestScriptNumber
	"self new getLatestScriptNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'script*' match: each ].
	upfroms := upfroms collect: [:each | (each asString allButFirst: 6)].
	upfroms := upfroms reject: [:each | '*Log*' match: each ].
	upfroms := upfroms reject: [:each | '*XXX*' match: each ].
	upfroms := upfroms collect: [:each | each asNumber].
	^ upfroms asSortedCollection last
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 10/17/2009 12:33'!
getLatestUpdateNumber
	"self new getLatestUpdateNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'update*' match: each ].
	upfroms := upfroms collect: [:each | [(each asString last: 5) asNumber] on: Error do: [0]].
	^ upfroms asSortedCollection last! !

!ScriptLoader methodsFor: 'accessing' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			self
				installGofer;
				gofer ]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'CarloTeixeira 8/11/2010 00:37'!
inboxRepository
	^ inboxRepository ifNil: [inboxRepository :=  MCHttpRepository inboxRepository]
	! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 7/10/2009 18:07'!
installGofer
	"self new installGofer"
	
	self class loadLatestPackage: 'Gofer' from: 'http://source.lukas-renggli.ch/flair'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 14:46'!
installRepository: aString for: packageName

	(MCWorkingCopy allManagers select: [:each | each package name = packageName])
		first repositoryGroup
		addRepository: (MCHttpRepository new location: aString ; user: '' ; password: '')
		! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'alain.plantec 2/6/2009 15:49'!
installVersionInfo
	"self new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' translated initialAnswer: '3.9' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	
! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 3/14/2010 21:13'!
installingInstaller
	"self new installingInstaller"

	| mc files fileToLoad version |
	mc := Smalltalk globals
		at: #MCHttpRepository
		ifPresent: [ :repoClass | repoClass location: 'www.squeaksource.com/Installer' user: 'squeak' password: 'squeak' ].
	files := mc readableFileNames
		asSortedCollection: [ :a :b | 
			[ (a findBetweenSubStrs: #($.)) allButLast last asInteger > (b findBetweenSubStrs: #($.)) allButLast last asInteger ]
				on: Error
				do: [ :ex | false ] ].
	fileToLoad := files detect: [ :aFile | aFile beginsWith: 'Installer-Core' ] ifNone: [ nil ].
	version := mc versionFromFileNamed: fileToLoad.
	version workingCopy repositoryGroup addRepository: mc.
	mc creationTemplate: mc asCreationTemplate.
	version load.
	^ Smalltalk globals at: #Installer! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 8/14/2008 16:03'!
latestScriptLoaderPackageIdentificationString
	"ScriptLoader new latestScriptLoaderPackageIdentificationString"
	
	^  self allCurrentVersions detect: [:each | 'ScriptLoader*' match: each ]
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'Jb 10/23/2010 12:14'!
launchUpdate

	UpdateStreamer new updateFromServer! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:06'!
loadLatestScriptloader
	"self new loadLatestScriptloader"
	
	self class 
		loadLatestPackage: 'ScriptLoader', self currentMajorVersionNumberWithoutDot 
		fromSqueaksource: 'Pharo' 
	

! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 10/23/2010 15:03'!
loadLatestUpdateList
	"fetch the latest version of the update.list on the server"
	
	| listToUse lastUpdate |
	listToUse := (HTTPClient httpGet: UpdateStreamer new updateFolderURL , 'updates.list') contents.
				
	listToUse linesDo: [:each | lastUpdate := each].
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			FileDirectory default
				forceNewFileNamed: 'updates.list'
				do: [:stream | stream nextPutAll: listToUse]]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'nice 1/5/2010 15:59'!
loadOneAfterTheOther: aCollection merge: aBoolean
	
	(self newerVersionsIn: aCollection)
		do: [:fn | | loader |
			loader := aBoolean
				ifTrue: [ MCVersionMerger new ]
				ifFalse: [ MCVersionLoader new].
			loader addVersion: (self repository loadVersionFromFileNamed: fn).
			aBoolean
				ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
							request merger conflicts isEmpty
								ifTrue: [request resume: true]
								ifFalse: [request pass]]]
				ifFalse: [loader load]]
  	  	displayingProgress: 'Loading versions...'.
	

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'adrian_lienhard 2/21/2009 13:40'!
loadOneAfterTheOther: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadOneAfterTheOther: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			self loadOneAfterTheOther: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
loadPackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		version load]! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'michael.rueger 1/13/2009 15:26'!
loadTogether: aCollection merge: aBoolean
	| loader |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	(self newerVersionsIn: aCollection)
		do: [:fn | loader addVersion: (self loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader hasVersions ifTrue: [loader load]]

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 5/10/2008 12:41'!
loadTogether: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadTogether: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			 self loadTogether: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'private' stamp: 'michael.rueger 1/13/2009 15:25'!
loadVersionFromFileNamed: fn
	| version |
	version := self repository loadVersionFromFileNamed: fn.
	^version
		ifNil: [self inboxRepository loadVersionFromFileNamed: fn]! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 4/4/2008 14:47'!
log: aString

	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/15/2008 18:30'!
logContents

	^ self logStream contents! !

!ScriptLoader methodsFor: 'log' stamp: 'adrian_lienhard 3/16/2009 21:30'!
logStream
	^ LogStream ifNil: [
		LogStream := ReadWriteStream on: (String new: 1000)]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
mergePackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles
		do: [ :name | | version |
			version := self class defaultMCWaitingFolder  versionFromFileNamed: name.
			version merge.
			]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'AdrianLienhard 6/5/2010 11:08'!
metacelloRepository
	^ (MCHttpRepository 
		location: 'http://www.squeaksource.com/MetacelloRepository'
		user: ''
		password: '')
	! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:35'!
newGenerateNewUpdateMethod
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:25'!
newGenerateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	"this version change the script to only "
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '^ '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr'.
	^ str contents! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 10/13/2005 21:44'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		MCWorkingCopy allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ScriptLoader methodsFor: 'utils' stamp: 'sd 2/4/2008 16:09'!
openWindow: contents label: aLabel

	StringHolder new 
		contents: contents ;
		openLabel: aLabel! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 7/17/2010 13:35'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'AST*'
			'*Refactoring*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
			'*OB-*'
			'OmniBrowser*'
		).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:23'!
prepareNewUpdate
	self launchUpdate.
	self loadLatestScriptloader.
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodate ifFalse: [self loadLatestUpdateList].
	self checkImageIsUptodate ifFalse: [
		^ self inform: 'Your update.list and your image are not in sync!! Please use a fresh image and download the latest update.list and start over. May be you are doing a rollback and you should remove the bogus ScriptLoader version from the Pharo repository' ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	self inform: 'The new version number is ' , self currentUpdateVersionNumber asString , '. Ready to apply changes now.', String cr, 'You are now running in image ', (FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName)).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 21:07'!
publishChanges
	| username password changescriptname changesetFilename str strings|
	(FileStream isAFileNamed: 'PharoPass.txt') 
		ifTrue: [ str := FileStream fileNamed:  'PharoPass.txt'. 
				strings := str contents substrings.
				username := strings first.
				password := strings second] 
		ifFalse: [ username := UIManager default request: 'Pharo repository login'.
			     password := UIManager default requestPassword: 'Pharo repository password'.].

	self setToRepositoriesPassword: password to: username.
	
	changescriptname := UIManager default request: 'Changeset name (no space)' initialAnswer: 'WhatAsChanged'.
	changesetFilename := self CSForLastUpdateAndPatchUpdatesList: changescriptname.
	self copyPackagesFromWaitingFolderToHomeRepository.
	self announceOnMailingList.
	self inform: 'All packages have been uploaded to the Pharo repository.
Remaining manual steps:
1) ./upFiles ',changesetFilename,'
2) ./upFiles updates.list
3) Announce new update on mailing list'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 22:30'!
removeAllHTTPRepositories: aColl
	"self new removeAllRepositories: 
			#('http://source.squeakfoundation.org/inbox/'
			 'http://source.squeakfoundation.org/39a/'
			 'http://source.squeakfoundation.org/Balloon/'
			 'http://source.squeakfoundation.org/Compression/'
			 'http://source.squeakfoundation.org/Graphics/'
			  'http://source.wiresong.ca/mc/')"
 
	
	MCWorkingCopy allManagers do: [:each | 
		aColl
			do: [:location | 
					each  repositoryGroup removeHTTPRepositoryLocationNamed: location]].
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:22'!
removeAllRepositories
	"self new removeAllRepositories"
	
	MCWorkingCopy allManagers do: [:each |  each  repositoryGroup initialize].
	MCRepositoryGroup default initialize.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'BenjaminVanRyseghem 11/28/2010 19:02'!
removeDejaVuFonts
	"Note, you need to close all windows to make the Deja Vu fonts being GCed"

	StandardFonts setDefaultFonts: #(
		(defaultFont: 'Accuny' 10)
		(codeFont: 'Accuny' 10)
		(listFont: 'Accuny' 10)
		(menuFont: 'Accuny' 10)
		(windowTitleFont: 'Accuny' 10)
		(balloonFont: 'Accuny' 10)
		(buttonFont: 'Accuny' 10)).
	TextSharedInformation removeKey: 'Bitmap DejaVu Sans'! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:06'!
removeScriptMethods
	"self new removeScriptMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - scripts') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:04'!
removeUpdateMethods

	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - updates') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:41'!
repository
	^ repository ifNil: [
		repository := MCHttpRepository new
			location:  'http://www.squeaksource.com/Pharo';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:48'!
repository310
	^ repository310 ifNil: [
		repository310 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/310';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repository39
	^ repository39 ifNil: [
		repository39 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/39a';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:42'!
repository: aRepository
	repository := aRepository! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/14/2009 10:32'!
repositoryMC
	^ repositoryMC ifNil: [
		repositoryMC := MCHttpRepository new
			location:  'http://source.wiresong.ca/mc';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repositorySqueakTrunk
	^ repositorySqueakTrunk ifNil: [
		repositorySqueakTrunk := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/trunk';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:59'!
repositoryTaskForces
	^ repositoryTaskForces ifNil: [
		repositoryTaskForces := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTaskForces';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/26/2009 07:47'!
repositoryTreated
	^ repositoryTreated ifNil: [
		repositoryTreated := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTreatedInbox';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:30'!
saveAsImageAsTestImage
	"Now you can run tests and see and go back to the previous image
	and do that go and back.... then after you can decide to freeze"

	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-imageForTestsFor')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'DamienCassou 9/8/2009 14:42'!
saveAsNewImageWithCurrentReleaseName
	|name|
	name := FileDirectory default
				nextNameFor: ('releasePharo-',  self currentUpdateVersionNumber asString)
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:31'!
saveAsNewImageWithCurrentReleaseNameToPublish
	"If the reload failed and you do not want to lose time reload all the cs and packages... you can now restart from the image saved now"
	
	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-releasePharoToPublish')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'al 11/1/2008 18:33'!
saveChangedPackagesIntoWaitingFolder
	self currentChangedPackages do: [:each |
		self
			saveInToReloadCachePackage: each
			with: self commentForCurrentUpdate]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 11/9/2010 18:38'!
saveImageForRunningTests

	| comment commentQuoted st resuming |
	resuming := false.
	SmalltalkImage current saveSession
		ifFalse: [ resuming := true].
	resuming ifTrue: [
		self saveAsImageAsTestImage.
	
		self inform: 'Now you can use this image named ''Test'' to run the tests and come back to fix problems in the \ previous one and eventually freeze it by selecting the next step, in either one.' withCRs]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/2/2008 00:31'!
saveInToReloadCachePackage: aWorkingCopy with: aMessageString
	self
		savePackage: aWorkingCopy
		in: self class defaultMCWaitingFolder
		with: aMessageString! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/28/2010 20:06'!
saveLatestScriptLoaderToHome
	"self new saveLatestScriptLoaderToHome"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader*' match: each  package name].
	self repository storeVersion: r first newVersion.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:31'!
saveLatestScriptLoaderToWaitingFolder
	"self new saveLatestScriptLoaderToWaitingFolder"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader', self currentMajorVersionNumberWithoutDot, '*' match: each  package name].
	self
		saveInToReloadCachePackage: r first
		with: self commentForCurrentUpdate! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 10/20/2009 11:28'!
savePackage: aWorkingCopy in: aRepository with: aMessageString
	" | sc |
	  sc := self new.
	  sc savePackage: (self new workingCopyFromPackageName: 'ScriptLoader11') 
		in: MCCacheRepository default
		with: 'this is test to automate dirty package saving in cache'"

	aRepository storeVersion: (aWorkingCopy 
		newVersionWithName: aWorkingCopy uniqueVersionName
		message: aMessageString)! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/19/2011 12:28'!
script0! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/19/2011 15:28'!
script1! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 15:20'!
script10

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.815.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.518.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 17:01'!
script11

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.815.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.521.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 17:27'!
script12

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.815.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.505.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.522.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 18:31'!
script13

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.816.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.506.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-StephaneDucasse.819.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.434.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.522.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 18:46'!
script14

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.816.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.506.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-StephaneDucasse.819.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.21.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.435.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.523.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/22/2011 09:56'!
script15

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.817.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.375.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.21.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.435.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.523.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/22/2011 19:52'!
script16

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.817.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.377.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.436.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.523.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.24.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/24/2011 13:21'!
script17

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.818.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.378.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.436.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.24.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/25/2011 13:15'!
script18

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.819.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.378.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.26.mcz
SimpleMorphic-MarcusDenker.11.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.437.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.107.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.25.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/26/2011 09:28'!
script19

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.820.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.380.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.26.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/19/2011 15:46'!
script2

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.72.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.810.mcz
KernelTests-MarcusDenker.303.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.816.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.369.mcz
RecentSubmissions-StephaneDucasse.60.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.15.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.261.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/26/2011 11:32'!
script20

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.821.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.381.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.26.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/26/2011 14:31'!
script21

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.821.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.381.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.27.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 14:49'!
script22

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.191.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.822.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.27.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 15:18'!
script23

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.191.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.822.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 16:22'!
script24

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.824.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 17:18'!
script25

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.824.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.525.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 18:03'!
script26

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.824.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.525.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/29/2011 12:02'!
script27

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.526.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/29/2011 12:11'!
script28

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.527.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/29/2011 13:32'!
script29

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/20/2011 10:38'!
script3

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.810.mcz
KernelTests-MarcusDenker.303.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.816.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.371.mcz
RecentSubmissions-StephaneDucasse.60.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.15.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.261.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/30/2011 12:41'!
script30

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-MarcusDenker.22.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/31/2011 13:43'!
script31

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/31/2011 14:02'!
script32

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/31/2011 16:57'!
script33

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.827.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/20/2011 12:58'!
script4

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.816.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-StephaneDucasse.60.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/20/2011 22:12'!
script5

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.817.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/21/2011 10:41'!
script6

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/21/2011 11:09'!
script7

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/21/2011 12:56'!
script8

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.813.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.518.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 14:50'!
script9

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.813.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.518.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/13/2010 22:30'!
setToRepositoriesPassword: aPassword to: aUser
	"self new setToRepositoriesPassword: 'sd' to: 'zork'"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllHTTPRepositories: {self repository locationWithTrailingSlash . self inboxRepository locationWithTrailingSlash}. 
	self repository password: aPassword.
	self repository user: aUser.
	self inboxRepository password: aPassword.
	self inboxRepository user: aUser.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:07'!
setUpdateAndScriptVersionNumbers
	CurrentUpdateVersionNumber := self getLatestUpdateNumber + 1.
	CurrentScriptVersionNumber := self getLatestScriptNumber + 1.! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 11/8/2010 22:09'!
shortImageName
	"should be removed when the version  will be integrated in SmalltalkImage"
	
	^ FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName).! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 11/13/2010 22:21'!
theScriptLoaderPackageName
	^'ScriptLoader',  CurrentMajorVersionNumber asString copyWithout: $. ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:58'!
unloadPackage: aString
	"self new unloadPackage: 'Sixx'"
	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'stephane.ducasse 2/6/2009 17:36'!
unloadPackageNamed: aString
	"self new workingCopyFromPackageName: 'CollectionExtensions' "
	
	^ (self workingCopyFromPackageName: aString) unload
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 7/15/2006 20:39'!
unloadPackages
	"ScriptLoader new unloadPackages"
	
	| copies namesOfpackagesToUnload |
	namesOfpackagesToUnload := self packagesToUnload. 
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	(copies select: [:each | namesOfpackagesToUnload anySatisfy: [:ea | ea match: each package name ]])
		do: [:z | z unload].! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/19/2011 15:42'!
update13000! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/19/2011 15:41'!
update13001! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/19/2011 15:46'!
update13002
	"self new update13002"
	self withUpdateLog: 'Issue 3422:	Use UIManager instead of Workspace
Issue 3509:	Multi-part MIME support for MailMessage
'.
	self loadTogether: self script2 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/20/2011 10:38'!
update13003
	"self new update13003"
	self withUpdateLog: 'Issue 3555:	HelpBrowser shoudl display Help as title, already integrated but reverted
Issue 3553:	GeneralScrollPane should support both spaceFill and shrinkWrap
Issue 3543:	Merge latest Glamour theme
'.
	self loadTogether: self script3 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/20/2011 12:58'!
update13004
	"self new update13004"
	self withUpdateLog: 'Issue 3558:	Delete empty package ScriptLoader12.
Issue 3552:	Delete Package DeleteMe
Issue 3550:	MenuItemMorph>>mouseDown: has unnecessary check
Issue 3468:	Perform and context frame size primitive tests
Issue 3441:	Tests for Polymorph
Issue 3378:	Process remove depende to UIManager
Issue 3557:	[Feature]: Setting for easy select i.e. selecting in the world by dragging'.
	self loadTogether: self script4 merge: false.
	ScriptLoader new deletePackage: 'DeleteMe'.
ScriptLoader new deletePackage: 'ScriptLoader12'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/20/2011 22:12'!
update13005
	"self new update13005"
	self withUpdateLog: 'Issue 3560:	Clean of RML
Issue 3559:	Remodularization of BalloonMorph'.
	self loadTogether: self script5 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/21/2011 10:41'!
update13006
	"self new update13006"
	self withUpdateLog: 'Issue 3556:	PluggableTextMorph(Object)>>doesNotUnderstand: #stylerStyled:'.
	self loadTogether: self script6 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/21/2011 11:09'!
update13007
	"self new update13007"
	self withUpdateLog: 'Issue 3520:	Workspaces do not recognize previously evaluated temps'.
	self loadTogether: self script7 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/21/2011 12:56'!
update13008
	"self new update13008"
	self withUpdateLog: 'Issue 3564:	Comparison of source references (for sorting)
Issue 3179:	Failing Tests for Monticello'.
	self loadTogether: self script8 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 14:50'!
update13009
	"self new update13009"
	self withUpdateLog: '-  Issue 3527:	Generator. Thanks Ralph Boland'.
	self loadTogether: self script9 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 15:20'!
update13010
	"self new update13010"
	self withUpdateLog: '- Issue 3361:	CompiledMethod copy. Thanks Gabriel Barbuto.'.
	self loadTogether: self script10 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 17:01'!
update13011
	"self new update13011"
	self withUpdateLog: '- Issue 2757:	Refactor StringHolder. Thanks Guillermo Polito.'.
	self loadTogether: self script11 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 17:36'!
update13012
	"self new update13012"
	self withUpdateLog: '- Issue 3440:	Cycle in Monticello removed.
- Little workspace fixes'.
	self loadTogether: self script12 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 18:31'!
update13013
	"self new update13013"
	self withUpdateLog: '- Categorization of deprecated methods.'.
	self loadTogether: self script13 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 18:47'!
update13014
	"self new update13014"
	self withUpdateLog: '- Issue 3569:	Error logging cleanup. Thanks Igor Stasenko.'.
	self loadTogether: self script14 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/22/2011 09:56'!
update13015
	"self new update13015"
	self withUpdateLog: 'Issue 3500:	Create deprecated13
Issue 3563:	PCCByCompilationTest tests sometimes fail randomly
Issue 3179:	Failing Tests for Monticello
Issue 3570:	EdgeGripMorph DNU when resizing'.
	self loadTogether: self script15 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/22/2011 19:52'!
update13016
	"self new update13016"
	self withUpdateLog: 'Issue 3566:	Changes needed to update Sound for 1.2
Issue 3380:	UnhandleError remove dependence to UIManager'.
	self loadTogether: self script16 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/24/2011 13:21'!
update13017
	"self new update13017"
	self withUpdateLog: 'Issue 3580:	Some trivial code-critique cleanups
Issue 3582:	RecentMessageList should be reseted in #cleanUpForRelease'.
	self loadTogether: self script17 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/25/2011 13:15'!
update13018
	"self new update13018"
	self withUpdateLog: 'Issue 3593:	NoneInteractive UIManager
Issue 3051:	ContextPart>>objectSize
Issue 3335:	[Kernel Dependencies] Number>>@'.
	self loadTogether: self script18 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/26/2011 09:28'!
update13019
	"self new update13019"
	self withUpdateLog: 'Issue 3583:	Shout should only be active in code panes
Issue 3594:	Expander needs tweaking to enable resize in a TableLayout
Issue 3590:	AntiAliased fix
Issue 3596:	2nd part Headless'.
	self loadTogether: self script19 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/26/2011 11:33'!
update13020
	"self new update13020"
	self withUpdateLog: 'Issue 3596:	2nd part Headless (3rd part)
Issue 3594:	Expander needs tweaking to enable resize in a TableLayout (part 2)'.
	self loadTogether: self script20 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/26/2011 14:31'!
update13021
	"self new update13021"
	self withUpdateLog: 'Issue 3596:	2nd part Headless (again...)'.
	self loadTogether: self script21 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 14:49'!
update13022
	"self new update13022"
	self withUpdateLog: '- Issue 3597:	Fix RemoteString API. Thanks Benjamin van Ryseghem. 
- Fixed bold application in a text.
- Removed a self haltOnce: 2 in mouseEnter.
- Now we do not read back code annotation such as bold and italic. The idea is to only store code without styling annotation outside the code. It will simplify the rewrite of the system. '.
	self loadTogether: self script22 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 15:18'!
update13023
	"self new update13023"
	self withUpdateLog: '- Issue 3377:	AppRegistry remoce dependence to UIManager. Thanks Benjamin van Ryseghem.
	
- Issue 3379:	ToolSet remove dependence to UIManager. Thanks Benjamin van Ryseghem.'.
	self loadTogether: self script23 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 16:22'!
update13024
	"self new update13024"
	self withUpdateLog: '- Repackaging a lot of classes and creating UI-Basic for Model and RealEstateAgent.'.
	self loadTogether: self script24 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 17:18'!
update13025
	"self new update13025"
	self withUpdateLog: '- Issue 3614:	Fix finder with * expressions!!
- remove SelectorBrowser.
- Issue 3616:	SyntaxError listMenu: fixes
- Less ParagraphEditor references.'.
	self loadTogether: self script25 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 18:04'!
update13026
	"self new update13026"
	self withUpdateLog: '- Fully Deprecate ParagraphEditor
- Object>>notifyWithLabel: deprecated
- Fix Pharo debug log
'.
	self loadTogether: self script26 merge: false.
	Compiler recompileAll.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/29/2011 12:02'!
update13027
	"self new update13027"
	self withUpdateLog: '- Deprecate Object>>notifyWithLabel:
- Issue 3618:	logError: aString inContext: aContext to: is used and it is deprecated	'.
	self loadTogether: self script27 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/29/2011 12:11'!
update13028
	"self new update13028"
	self withUpdateLog: '- Fully deprecate ParagraphEditor'.
	self loadTogether: self script28 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/29/2011 13:32'!
update13029
	"self new update13029"
	self withUpdateLog: '- Issue 3608:	Fix failing MessageTally tests. Thanks Marcus Denker.
- Issue 3610:	Should remove Morphic-Undo. Thanks Alain Plantec.'.
	self loadTogether: self script29 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/30/2011 12:41'!
update13030
	"self new update13030"
	self withUpdateLog: 'Issue 2586:	line breaks lost on Linux when copying from one pharo image to another
'.
	self loadTogether: self script30 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/31/2011 13:43'!
update13031
	"self new update13031"
	self withUpdateLog: 'Issue 3626:	Clipboard broken on Unix. '.
	self loadTogether: self script31 merge: false.
	Clipboard initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/31/2011 14:03'!
update13032
	"self new update13032"
	self withUpdateLog: '- Issue 3482:	InterimSoundMorph references to SketchMorph.
- Issue 3624:	LeftOver of Smalltalk and SystemDictionary. 
'.
	self loadTogether: self script32 merge: false.
	SoundService reset. 
DummySoundSystem initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/31/2011 16:57'!
update13033
	"self new update13033"
	self withUpdateLog: '- Issue 3630:	Add ensureCr convenience method.
- Issue 3562:	Deferred UI messages executed slowly. Thanks Ricardo Moran!!!!'.
	self loadTogether: self script33 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:09'!
updateUpdatesList: aString
	"ScriptLoader new updateUpdatesList: 'cleanUpMethods'"
	
	| str |
	str := FileDirectory default oldFileNamed: 'updates.list'.
	[	str
			setToEnd;
			cr;
			nextPutAll: self currentUpdateVersionNumber asString;
			nextPutAll: '-Pha-', aString, '.cs' ]
		ensure: [ str close ]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'lr 3/14/2010 21:13'!
verifyNewUpdate
	self repository: self class defaultMCWaitingFolder.
	self class loadLatestPackage: 'ScriptLoader' fromRepository: self repository.
	self perform: ('update' , self getLatestUpdateNumber asString) asSymbol.
	(self confirm: 'Completed loading the new update. Run all test now?')
		ifTrue: [ 
			Author fullName: 'tester'.
			Smalltalk globals at: #TestRunner ifPresent: [ :class | class open model runAll ] ]! !

!ScriptLoader methodsFor: 'private' stamp: 'al 11/1/2008 18:19'!
waitingFolderMCZFiles
	^ self class defaultMCWaitingFolder allFileNames
		reject: [:each | each =  '.DS_Store']! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/24/2008 16:45'!
withUpdateLog: aString

	self logStream nextPutAll: ' ------------------------------------------------------' ; cr.
	self logStream nextPutAll: thisContext sender selector asString. 
	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'sd 3/24/2008 17:31'!
workingCopyFromPackageName: aString
	"self new workingCopyFromPackageName: '39Deprecated' "
	
	|pa|
	pa := MCPackage named: aString.
	^ pa workingCopy 
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 7/8/2006 18:20'!
writeCS: extensionAndNumber forUpdate: updateNumber
	"ScriptLoader new writeCS: '-sd.210' forUpdate: 7037"
	
	self writeCS: extensionAndNumber forUpdate: updateNumber withName: 'changeMe'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 2/25/2010 18:09'!
writeCS: extensionAndNumber forUpdate: updateNumber withName: aSt
	"ScriptLoader new writeCS: '-md.2929' forUpdate: 7049 withName: 'cleanUpMethods'"
	

	FileDirectory default 
		forceNewFileNamed:  updateNumber asString, 'update', aSt, '.cs'
		do: [ :stream | self generateCS: extensionAndNumber fromUpdate: updateNumber on: stream].
! !
ScriptLoader initialize!
